@@ -1,5 +1,5 @@
 """
-Quantum circuit: state simulator
+Quantum circuit: the state simulator
 """
 # pylint: disable=invalid-name
 
@@ -216,7 +216,7 @@ class Circuit:
             matrix = gates.matrix_for_gate(getattr(gates, g)())
             matrix = gates.bmatrix(matrix)
             doc = """
-            Apply %s gate on the circuit.
+            Apply **%s** gate on the circuit.
 
             :param index: Qubit number than the gate applies on.
                 The matrix for the gate is
@@ -227,16 +227,16 @@ class Circuit:
 
             :type index: int.
             """ % (
-                g,
+                g.upper(),
                 matrix,
             )
             docs = """
-            Apply %s gate on the circuit.
+            Apply **%s** gate on the circuit.
 
             :param index: Qubit number than the gate applies on.
             :type index: int.
             """ % (
-                g
+                g.upper()
             )
             if g in ["rs"]:
                 getattr(cls, g).__doc__ = docs
@@ -262,14 +262,14 @@ class Circuit:
                 ),
             )
             doc = """
-            Apply %s gate with parameters on the circuit.
+            Apply **%s** gate with parameters on the circuit.
 
             :param index: Qubit number than the gate applies on.
             :type index: int.
             :param vars: Parameters for the gate.
             :type vars: float.
             """ % (
-                g
+                g.upper()
             )
             getattr(cls, g).__doc__ = doc
             getattr(cls, g.upper()).__doc__ = doc
@@ -398,7 +398,7 @@ class Circuit:
         self._nodes.append(gate)
 
         # actually apply single and double gate never directly used in the Circuit class
-        # and don't use, directly use general gate function as it is more richful in feature
+        # and don't use, directly use general gate function as it is more diverse in feature
 
     def apply_general_gate(
         self,
@@ -837,8 +837,7 @@ class Circuit:
         ] = None,
     ) -> float:  # DRY
         sites = len(index)
-        if isinstance(kraus[0], tn.Node):
-            kraus = [k.tensor for k in kraus]
+        kraus = [k.tensor if isinstance(k, tn.Node) else k for k in kraus]
         if prob is None:
             prob = [
                 backend.real(backend.trace(backend.adjoint(k) @ k) / k.shape[0])
@@ -913,7 +912,7 @@ class Circuit:
         fallback_weight_i = 0
         len_kraus = len(kraus)
         for i in tf.range(len_kraus):  # breaks backend agnostic
-            # nested for and if, if tensor inner must come with for in tensor outter, s.t. autograph works
+            # nested for and if, if tensor inner must come with for in tensor outer, s.t. autograph works
             weight = calculate_kraus_p(i)
             if weight > fallback_weight:
                 fallback_weight_i = i
@@ -954,7 +953,8 @@ class Circuit:
         # vmap, grad, vvag are all fine for this function
         # layerwise jit technique can greatly boost the staging time, see in /examples/mcnoise_boost.py
         sites = len(index)
-        kraus_tensor = [k.tensor for k in kraus]
+        kraus_tensor = [k.tensor if isinstance(k, tn.Node) else k for k in kraus]
+        # kraus_tensor = [k.tensor for k in kraus]
 
         # tn with hole
         newnodes, newfront = self._copy()
@@ -1194,7 +1194,7 @@ class Circuit:
     ) -> Tuple[Tensor, Tensor]:
         """
         Take measurement to the given quantum lines.
-        This method implementated by jit is about 100 times faster than unjit version!
+        This method implemented by jit is about 100 times faster than unjit version!
 
         :param index: Measure on which quantum line.
         :type index: int
@@ -1245,6 +1245,7 @@ class Circuit:
 
     def perfect_sampling(self) -> Tuple[str, float]:
         """
+        Sampling bistrings from the circuit output.
         Reference: arXiv:1201.3974.
 
         :return: Sampled bit string and the corresponding theoretical probability.
@@ -1328,6 +1329,7 @@ class Circuit:
         return qir2qiskit(qir, n=self._nqubits)
 
     def draw(self, **kws: Any) -> Any:
+        # TODO(@Xinghan): The example part of the documentation doesn't load as you put your mouse on the draw dunction
         """
         Visualise the circuit.
         This method recevies the keywords as same as qiskit.circuit.QuantumCircuit.draw.
@@ -1370,8 +1372,8 @@ def to_graphviz(
     engine: str = "neato",
 ) -> graphviz.Graph:
     """
-    Not an ideal visualization for quantum circuit, but reserve here as a general approch to show tensornetwork
-    [Deperacted, use ``qir2tex instead``]
+    Not an ideal visualization for quantum circuit, but reserve here as a general approach to show the tensornetwork
+    [Deprecated, use ``tensorcircuit.vis.qir2tex instead``]
     """
     # Modified from tensornetwork codebase
     nodes = c._nodes
